@@ -5,6 +5,7 @@ import warnings
 
 import matplotlib.pyplot as plt
 from matplotlib.lines import Line2D
+from math import floor
 
 from showy.preprocess_utils import preprocess_layout
 from showy.validation import validate_layout
@@ -120,9 +121,13 @@ def _build_new_graph(ax, graph_layout, dataframes):
     for data_number, dataframe in enumerate(dataframes):
         x = dataframe[graph_layout["x_var"]]
         for curve_number, curve_layout in enumerate(graph_layout["curves"]):
-            custom_style = _custom_cycler_iterate(curve_number, data_number)
-
-            ax.plot(x, dataframe[curve_layout["var"]], **custom_style)
+            symbols_markevery = _symbols_markevery(x)
+            custom_style = _custom_cycler_iterate(curve_number, data_number, symbols_markevery)
+            try :
+                ax.plot(x, dataframe[curve_layout["var"]], **custom_style)
+            except KeyError:
+                print(f"Could not find the key {curve_layout['var']} in current dataframe")
+            
 
     # improve legends
     handles = []
@@ -145,7 +150,7 @@ def _build_new_graph(ax, graph_layout, dataframes):
         ax.legend(handles=handles, loc=0)
 
 
-def _custom_cycler_iterate(index, family_index=0):
+def _custom_cycler_iterate(index, family_index=0, markevery=None):
     """Returns a dict with keys and values in accordance to the Matplotlib
     syntax.
 
@@ -157,13 +162,16 @@ def _custom_cycler_iterate(index, family_index=0):
     custom_cycler = ['#4477AA', '#66CCEE', '#228833', '#CCBB44', '#EE6677',
                      '#AA3377', '#BBBBBB']
     custom_linestyles = ['solid', 'dashed', 'dotted', 'dash']
+    custom_symbols = ["d", "o", "v", "^", ">", "<", "s"]
 
     index_ = index % len(custom_cycler)
     family_index_ = family_index % len(custom_linestyles)
 
     custom_style = {
         'color': custom_cycler[index_],
-        'linestyle': custom_linestyles[family_index_]
+        'linestyle': custom_linestyles[family_index_],
+        'marker': custom_symbols[index_],
+        'markevery': markevery,
     }
 
     if index > len(custom_cycler):
@@ -173,3 +181,17 @@ def _custom_cycler_iterate(index, family_index=0):
         warnings.warn(f"More than {len(custom_linestyles)} types of curves on one graph")
 
     return custom_style
+
+def _symbols_markevery(x):
+    """compute indices where to show symbols
+
+    Args:
+        x (numpy array): x vector
+    """
+    nb_markers = 10
+    # set step between two symbols
+    step = floor(len(x) / (nb_markers-1))
+    # list of symbols indexes (first symbol at first index)
+    symbols_indexes = [k * step for k in range(nb_markers)]
+
+    return symbols_indexes
\ No newline at end of file
